@@ -1,8 +1,8 @@
 #!/usr/bin/perl -w
 use strict;
 use DBI;
-use DBIx::SQLCrosstab 1.15;
-use DBIx::SQLCrosstab::Format 0.06;
+use DBIx::SQLCrosstab 1.17;
+use DBIx::SQLCrosstab::Format 0.07;
 use Data::Dumper;
 
 my $dbh;
@@ -28,10 +28,8 @@ $dbh or die "Error in connection [ driver $driver ] ($DBI::errstr)\n";
 
 my $params = {
     dbh            => $dbh, 
-    op             => 'SUM',    
-    op_col         => 'salary', 
+    op             => [['COUNT','person_id'], [ 'SUM', 'salary']],    
     title          => 'TBD',
-    add_op         => [],
     title_in_header=> 1,
     remove_if_null => 1,        # remove columns with all nulls
     remove_if_zero => 1,        # remove columns with all zeroes
@@ -53,26 +51,26 @@ my $params = {
          { 
            id    => 'dept_id', 
            value => 'department',     
-           from  => 'departments' 
+           from  => 'xtab_departments' 
          },
          { 
            id    => 'cat_id',  
            value => 'category', 
-           from  => 'categories' 
+           from  => 'xtab_categories' 
          },
          { 
            id       => 'gender',   
            col_list => [ {id=>'f'}, {id =>'m'}],
-           from     => 'person' 
+           from     => 'xtab_person' 
          },
         ],
 
     from           => 
-        qq{person 
-            INNER JOIN locations 
-                ON (person.loc_id=locations.loc_id) 
-            INNER JOIN countries 
-                ON (countries.country_id=locations.country_id)
+        qq{xtab_person 
+            INNER JOIN xtab_locations 
+                ON (xtab_person.loc_id=xtab_locations.loc_id) 
+            INNER JOIN xtab_countries 
+                ON (xtab_countries.country_id=xtab_locations.country_id)
             },
 };
     
@@ -84,7 +82,7 @@ $params->{title} =  "personnel by "
                         $_->{value} : $_->{id}} @{$params->{cols}} );
 
 my $xtab1 = DBIx::SQLCrosstab::Format->new($params) 
-    or die "$DBIx::SQLCrosstab::errstr\n";    
+    or die "Error in \$xtab1 creation $DBIx::SQLCrosstab::errstr\n";    
 
 my $query = $xtab1->get_query ('#') 
     or die "$DBIx::SQLCrosstab::errstr\n";    
@@ -92,6 +90,26 @@ my $query = $xtab1->get_query ('#')
 my $recs = $xtab1->get_recs
     or die "$DBIx::SQLCrosstab::errstr\n"; 
 
+my @rows = (       
+            #{ col     => 'loc', alias => 'location'},
+            { col     => 'customer' },
+            #{ col     => 'class_name', alias =>'class'}
+);
+ 
+#
+# Add a database-dependent expression 
+#
+if ($driver eq 'mysql') {
+    unshift @rows, 
+        { col     => qq{date_format(sale_date,"%Y-%m")}, 
+          alias   => "'yyyy-mm'" };
+}
+elsif ($driver eq 'SQLite') {
+    unshift @rows, 
+        { col     => qq{substr(sale_date,1,7)}, 
+          alias   => "yyyy_mm" };
+}
+
 #
 # Using the alternative params setting
 #
@@ -100,52 +118,48 @@ my $recs = $xtab1->get_recs
 # First, create a dummy object
 #
 my $xtab2 =  DBIx::SQLCrosstab::Format->new('STUB')
-            or die "error in object creation ($DBIx::SQLCrosstab::errstr)\n";
+    or die "error in \$xtab2 creation ($DBIx::SQLCrosstab::errstr)\n";
     
 #
-# Then, pass parameters to it. You can do it one-by-one
+# Then, pass parameters to it. You can do it one-by-one ...
 #
 $xtab2->set_param( dbh => $dbh )
     or die "error adding mandatory parameters ($DBIx::SQLCrosstab::errstr)";
-            
+
 #
-# Or several ones at once
+# ... or several ones at once
 #
 $xtab2->set_param( 
-   op      => 'SUM',
-   op_col  => 'sale_amount',
-   rows    => [       
-                #{ col     => 'loc', alias => 'location'},
-                { col     => 'customer' },
-                #{ col     => 'class_name', alias =>'class'}
-              ],
+   op      => [ ['SUM', 'sale_amount'] ],
+   # op_col  => 'sale_amount',
+   rows    => \@rows,
    cols    => [
                 {
                     id    => 'country_id',
                     value => 'country',
-                    from  => 'countries'
+                    from  => 'xtab_countries'
                 },
                 { 
-                    id    => 'person.person_id', 
+                    id    => 'xtab_person.person_id', 
                     value => 'name',     
-                    from  => 'person' 
+                    from  => 'xtab_person' 
                 },
                 { 
-                    id    => 'class.class_id',   
+                    id    => 'xtab_class.class_id',   
                     value => 'class_name',     
-                    from  => 'class' 
+                    from  => 'xtab_class' 
                 },
               ],
   from    => 
-              qq{sales 
-                  INNER JOIN customers 
-                      ON (sales.customer_id=customers.customer_id) 
-                  INNER JOIN person 
-                      ON (sales.person_id=person.person_id)
-                  INNER JOIN class 
-                      ON (sales.class_id=class.class_id)
-                  INNER JOIN locations 
-                      ON (locations.loc_id=person.loc_id)
+            qq{xtab_sales 
+                INNER JOIN xtab_customers 
+                    ON (xtab_sales.customer_id=xtab_customers.customer_id) 
+                INNER JOIN xtab_person 
+                    ON (xtab_sales.person_id=xtab_person.person_id)
+                INNER JOIN xtab_class 
+                    ON (xtab_sales.class_id=xtab_class.class_id)
+                INNER JOIN xtab_locations 
+                    ON (xtab_locations.loc_id=xtab_person.loc_id)
                   },
 )
     or die "error adding mandatory parameters ($DBIx::SQLCrosstab::errstr)";
@@ -174,6 +188,7 @@ $xtab2->set_param(
 # Alternatively, you can save the query and the recordset
 # to a variable for further use
 #
+
 unless ($xtab2->get_query and $xtab2->get_recs) {
     die "$DBIx::SQLCrosstab::errstr";
 }
@@ -187,13 +202,15 @@ $xtab2->save_params("xtab2.pl") or die "$DBIx::SQLCrosstab::errstr";
 # Create a third object
 #
 my $xtab3 = DBIx::SQLCrosstab::Format->new('STUB')
-    or die "error in object creation ($DBIx::SQLCrosstab::errstr)\n";
+    or die "error in \$xtab3 creation ($DBIx::SQLCrosstab::errstr)\n";
 
 #
 # Use the saved parameters to set it up
 #
-$xtab3->load_params("xtab2.pl") or die "$DBIx::SQLCrosstab::errstr";
-$xtab3->set_param( dbh => $dbh) or die "$DBIx::SQLCrosstab::errstr";
+$xtab3->load_params("xtab2.pl") 
+    or die "\$xtab3 -> $DBIx::SQLCrosstab::errstr";
+$xtab3->set_param( dbh => $dbh) 
+    or die "\$xtab3 -> $DBIx::SQLCrosstab::errstr";
 
 unless ($xtab3->get_query and $xtab3->get_recs) {
     die "$DBIx::SQLCrosstab::errstr";
@@ -209,9 +226,7 @@ for my $xt (($xtab1, $xtab2, $xtab3)) {
     open HTML, ">$fname.html" 
         or die "can't create $fname.html\n";
     print HTML  $xt->html_header; 
-    print HTML  "<h3>",$xt->op, 
-                "(", $xt->op_col, ") ", 
-                $xt->{title}, "</h3>";
+    print HTML  "<h3>",$xt->op_list, " FROM ", $xt->{title}, "</h3>";
 
     my $table = $xt->as_html;
     $table =~ s/\bzzzz\b/total/g;
@@ -276,13 +291,20 @@ for my $xt (($xtab1, $xtab2, $xtab3)) {
     open STRUCT, ">$fname.pl" 
         or die "can't create $fname.pl\n";
     local $Data::Dumper::Indent=1;
-    print STRUCT Data::Dumper->Dump( [$xt->as_perl_struct('loh'),
+    print STRUCT Data::Dumper->Dump( 
+          [
+          $xt->as_perl_struct('loh'),
           $xt->as_perl_struct('losh'),
-          $xt->as_perl_struct('hoh')], ['loh','losh','hoh']);
+          $xt->as_perl_struct('hoh')
+          ], 
+          ['loh','losh','hoh']);
     close STRUCT;
     print "$fname.pl created\n";
+    #print map {"$_\n"} @{ $xt->{header_tree}->draw_ascii_tree};
+    #print map {"$_\n"} @{ $xt->{recs_tree}->draw_ascii_tree};
+    #print YAML::Dump( $xt->{header_tree});
+    #print YAML::Dump($xt->{recs_tree});
+    #print Dumper($xt->{recs_formats});
+    #print Dumper($xt->{header_formats});
 }
 
-print "\nNotice that, since \$xtab3 is a clone of \$xtab2,\n",
-       "table02* and table03* must be have the same contents.\n";
-
